@@ -50,7 +50,7 @@ TEST { show improper_list (list (1,3), 2) }
 
 TEST { regex_substitute sub{s/line \d+/line .../g},
            show improper_list ([1,3], {foo=> list("bar",sub{"f"})}) }
-  'improper_list([1, 3], +{foo => list(\'bar\', sub { \'DUMMY: FP::Show::t::__ANON__ at "lib/FP/Show/t.pm" line ...\' })})';
+  'improper_list([1, 3], +{foo => list(\'bar\', sub { "DUMMY" })})';
 
 my $s;
 TEST {
